@@ -78,7 +78,11 @@ sub runtest
             $result .= "concurrency 1\n";
             my $file = $tmpfile->clone;
             diag( "Writing 'concurrency 1' to file $tmpfile and my pid is '$$' vs parent '$pid'" ) if( $DEBUG );
-            $file->append( "concurrency 1\n" );
+            $file->append( "concurrency 1\n" ) || do
+            {
+                warn( "Error appending to file $file: ", $file->error, "\n" );
+            };
+            return( $file );
         }, { debug => $DEBUG, serialiser => $serialiser })->then(sub
         {
             diag( "[$medium] -> [$serialiser], [P1] Parameter received is '", overload::StrVal( $_[0] ), "'" ) if( $DEBUG );
@@ -97,7 +101,11 @@ sub runtest
             $result .= "concurrency 2\n";
             my $file = file( $tmpfile );
             diag( "[$medium] -> [$serialiser]: Appending 'concurrency 2' to $tmpfile and my pid is '$$' vs parent '$pid'" ) if( $DEBUG );
-            $file->append( "concurrency 2\n" );
+            $file->append( "concurrency 2\n" ) || do
+            {
+                warn( "Error appending to file $file: ", $file->error, "\n" );
+            };
+            return( $file );
         }, { debug => $DEBUG, timeout => 2, serialiser => $serialiser })->then(sub
         {
             diag( "[$medium] -> [$serialiser], [P2] Parameter received is '", overload::StrVal( $_[0] ), "'" ) if( $DEBUG );
